==> tine20-allinone_2020.03.4.tar.bz2: Admin/js/Admin-lang-ko_KR-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Admin **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Korean (Korea) (http://www.transifex.com/tine20/tine20/language/ko_KR/)\nLanguage: ko_KR\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Enable Application"
: ""

, "Disable Application"
: ""

, "Settings"
: ""

, "{0} Settings"
: ""

, "Search:"
: ""

, "Disabled"
: ""

, "Enabled"
: ""

, "Unknown status ({0})"
: ""

, "Displaying application {0} - {1} of {2}"
: ""

, "No applications to display"
: ""

, "Order"
: ""

, "Name"
: "이름"

, "Status"
: ""

, "Version"
: ""

, "Confirm"
: ""

, "Do you really want to delete the selected groups?"
: ""

, "Deleting group(s)..."
: ""

, "Failed"
: ""

, "Some error occurred while trying to delete the group."
: ""

, "Add Group"
: ""

, "Edit Group"
: ""

, "Delete Group"
: ""

, "Displaying groups {0} - {1} of {2}"
: ""

, "No groups to display"
: ""

, "ID"
: ""

, "E-mail"
: ""

, "Description"
: ""

, "Creation Time"
: ""

, "Created By"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Errors"
: ""

, "Please configure store for this field type"
: ""

, "Application, Applications"
: [
  ""

]
, "Record Class"
: ""

, "Given record class not found"
: ""

, "Cancel"
: ""

, "OK"
: ""

, "Configure store"
: ""

, "Model"
: ""

, "Custom field definition"
: ""

, "Text"
: ""

, "Textarea"
: ""

, "Number"
: ""

, "Date"
: ""

, "DateTime"
: ""

, "Time"
: ""

, "Boolean"
: ""

, "Search Combo"
: ""

, "Key Field"
: ""

, "Record"
: ""

, "Record List"
: ""

, "Type"
: ""

, "Label"
: ""

, "Length"
: ""

, "Required"
: ""

, "Custom field additional properties"
: ""

, "Tab Panel"
: ""

, "Group, Groups"
: [
  ""

]
, "Customfield already exists. Please choose another name."
: ""

, "Customfield, Customfields"
: [
  ""

]
, "This custom field is still in use!"
: ""

, "Are you sure you want to delete them?"
: ""

, "Yes"
: ""

, "No"
: ""

, "Config, Configs"
: [
  ""

]
, "Value"
: ""

, "Default ({0})"
: ""

, "Computer Name"
: ""

, "Default Addressbook for new contacts and groups"
: ""

, "Please wait"
: ""

, "Updating Tag"
: ""

, "Could not save tag ({0})"
: ""

, "Please fix the errors noted."
: ""

, "Allowed Contexts"
: ""

, "Context"
: ""

, "Account Rights"
: ""

, "View"
: ""

, "Use"
: ""

, "Tag Name"
: ""

, "Color"
: ""

, "Transferring {0}..."
: ""

, "Tag"
: ""

, "Add New Tag"
: ""

, "Edit Tag \"{0}\""
: ""

, "Do you really want to delete the selected tags?"
: ""

, "Deleting tag(s)..."
: ""

, "Add Tag"
: ""

, "Edit Tag"
: ""

, "Delete Tag"
: ""

, "Displaying tags {0} - {1} of {2}"
: ""

, "No tags to display"
: ""

, "Usage:&#160;"
: ""

, "Updating Memberships"
: ""

, "Could not save role."
: ""

, "Deleting role..."
: ""

, "Some error occurred while trying to delete the role."
: ""

, "Rights"
: ""

, "Members"
: ""

, "Role Name"
: ""

, "Role"
: ""

, "Add New Role"
: ""

, "Edit Role \"{0}\""
: ""

, "Do you really want to delete the selected roles?"
: ""

, "Deleting role(s)..."
: ""

, "Add Role"
: ""

, "Edit Role"
: ""

, "Delete Role"
: ""

, "Displaying roles {0} - {1} of {2}"
: ""

, "No roles to display"
: ""

, "Access Log, Access Logs"
: [
  "접속 로그"

]
, "Groups"
: ""

, "Applications"
: ""

, "Configs"
: ""

, "Domain is not allowed. Check your SMTP domain configuration."
: ""

, "Special characters are not allowed in login name."
: ""

, "Passwords do not match!"
: ""

, "Passwords match!"
: ""

, "Primary group"
: ""

, "Unix"
: ""

, "Home Directory"
: ""

, "Login Shell"
: ""

, "Windows"
: ""

, "Home Drive"
: ""

, "Login Time"
: "로그인 시간"

, "never logged in"
: ""

, "Home Path"
: ""

, "Logout Time"
: "로그아웃 시간"

, "never logged off"
: ""

, "Profile Path"
: ""

, "Password Last Set"
: ""

, "never"
: ""

, "Logon Script"
: ""

, "Password Can Change"
: ""

, "not set"
: ""

, "Password Must Change"
: ""

, "Kick Off Time"
: ""

, "Filesystem Quota"
: ""

, "Quota"
: ""

, "no quota set"
: ""

, "Current Filesystem usage"
: ""

, "IMAP Quota"
: ""

, "Current Mailbox size"
: ""

, "Sieve Quota"
: ""

, "Current Sieve size"
: ""

, "Information"
: ""

, "Last Login"
: ""

, "Domain not allowed"
: ""

, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
: ""

, "E-mail Alias"
: ""

, "Add an alias address..."
: ""

, "This alias can be used for sending e-mails."
: ""

, "Forwarding to self"
: ""

, "You are not allowed to set a forwarding e-mail address that is identical to the users primary e-mail or one of his aliases."
: ""

, "E-mail Forward"
: ""

, "Add a forwarding address..."
: ""

, "Forward Only"
: ""

, "Password confirmation"
: ""

, "Repeat password"
: ""

, "Ok"
: ""

, "Account"
: ""

, "First name"
: ""

, "Last name"
: ""

, "Login name"
: ""

, "Password"
: ""

, "OpenID"
: ""

, "enabled"
: ""

, "disabled"
: ""

, "expired"
: ""

, "blocked"
: ""

, "Invalid Status"
: ""

, "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
: ""

, "Expires"
: ""

, "Visibility"
: ""

, "Display in addressbook"
: ""

, "Hide from addressbook"
: ""

, "Saved in Addressbook"
: ""

, "Last login at"
: ""

, "don't know"
: ""

, "Last login from"
: ""

, "Password set"
: ""

, "User groups"
: ""

, "User roles"
: ""

, "Fileserver"
: ""

, "Filesystem"
: ""

, "IMAP"
: ""

, "SMTP"
: ""

, "User, Users"
: [
  "사용자"

]
, "Users"
: ""

, "Samba User, Samba Users"
: [
  ""

]
, "Email User, Email Users"
: [
  ""

]
, "Enable Account"
: ""

, "Disable Account"
: ""

, "Reset Password"
: ""

, "Reset Pin"
: ""

, "Display name"
: ""

, "E-mail usage"
: ""

, "Filesystem usage"
: ""

, "Password changed"
: ""

, "Set new password"
: ""

, "Please enter the new password:"
: ""

, "Set new pin"
: ""

, "Please enter the new pin:"
: ""

, "Group Name"
: ""

, "Only system accounts can be added to Addressbook group"
: ""

, "Group Members"
: ""

, "personal"
: ""

, "shared"
: ""

, "Container Hierarchy/Name"
: ""

, "Note for Owner"
: ""

, "Info"
: ""

, "Please create Resources in Addressbook or CoreData."
: ""

, "Container, Containers"
: [
  ""

]
, "Container Name"
: ""

, "Container Order"
: ""

, "Computer, Computers"
: [
  ""

]
, "Size"
: ""

, "Revision Size"
: ""

, "Total size of all available revisions"
: ""

, "Quota Usage"
: ""

, "Roles"
: ""

, "Containers"
: ""

, "Shared Tags"
: ""

, "Customfields"
: ""

, "Computers"
: ""

, "Server Information"
: ""

, "ActiveSync Devices"
: ""

, "E-mail Accounts"
: ""

, "Admin"
: ""

, "Refresh"
: ""

, "Feature is disabled by configuration."
: ""

, "IP Address"
: "IP 주소"

, "Client Type"
: "사용자 유형"

, "Session ID"
: "세션 ID"

, "Login Name"
: "로그인 이름"

, "Result"
: "결과"

, "user blocked"
: "차단된 사용자"

, "password expired"
: "비밀번호 만료"

, "user disabled"
: "삭제된 사용자"

, "invalid password"
: "비밀번호 오류"

, "ambiguous username"
: "알수 없는 사용자 이름"

, "user not found"
: "사용자 없음"

, "failure"
: "실패"

, "success"
: "성공"

, "Default IMAP user settings"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Admin Application."
: ""

, "Prevent special chars in login name"
: ""

, "Force retype of new password in user edit dialog"
: ""

, "Your container has been changed"
: ""

, "Your container has been changed by %1$s %2$sNote: %3$s"
: ""

, "Manage access log"
: ""

, "Delete access log entries."
: ""

, "Manage accounts"
: ""

, "Add and edit users and groups, add group members, change user passwords."
: ""

, "Manage e-mail accounts"
: ""

, "Add and edit shared and personal e-mail accounts."
: ""

, "Manage applications"
: ""

, "Enable and disable applications, edit application settings."
: ""

, "Manage roles"
: ""

, "Add and edit roles, add new members to roles, add application rights to roles."
: ""

, "Manage shared tags"
: ""

, "Add, delete and edit shared tags."
: ""

, "Manage computers"
: ""

, "Add, delete and edit (samba) computers."
: ""

, "Manage containers"
: ""

, "Add, delete and edit containers and manage container grants."
: ""

, "Manage customfields"
: ""

, "Add and edit customfields."
: ""

, "View access log"
: ""

, "View access log list."
: ""

, "View accounts"
: ""

, "View accounts list and details."
: ""

, "View e-mail accounts"
: ""

, "View shared and personal e-mail accounts."
: ""

, "View applications"
: ""

, "View applications list and details."
: ""

, "View roles"
: ""

, "View roles list and details."
: ""

, "View shared tags"
: ""

, "View shared tags list and details."
: ""

, "View computers"
: ""

, "View computers list and details."
: ""

, "View containers"
: ""

, "View personal and shared containers."
: ""

, "View customfields"
: ""

, "View customfields list."
: ""

, "View serverinfo"
: ""

, "View serverinfo list."
: ""

, "View quota usage"
: ""

, "View quota usage."
: ""









, "Application"
: ""

, "Group"
: ""

, "Customfield"
: ""

, "Config"
: ""

, "Access Log"
: "접속 로그"

, "User"
: "사용자"

, "Samba User"
: ""

, "Email User"
: ""

, "Container"
: ""

, "Computer"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Admin/js/Admin-lang-ko_KR-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Admin **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:46+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Korean (Korea) (http://www.transifex.com/tine20/tine20/language/ko_KR/)\nLanguage: ko_KR\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "ImportExportDefinition, ImportExportDefinitions"
: [
  ""

]
, "Application, Applications"
: [
  ""

]
, "User, Users"
: [
  "사용자"

]
, "Groups"
: ""

, "Roles"
: ""

, "Applications"
: ""

, "Containers"
: ""

, "Shared Tags"
: ""

, "Customfields"
: ""

, "Computers"
: ""

, "Access Log, Access Logs"
: [
  "접속 로그"

]
, "Log"
: ""

, "Server Information"
: ""

, "ActiveSync Devices"
: ""

, "E-mail Accounts"
: ""

, "Import Export Definitions"
: ""

, "Admin"
: ""

, "Refresh"
: ""

, "Disabled"
: ""

, "Feature is disabled by configuration."
: ""

, "Default Addressbook for new contacts and groups"
: ""

, "Computer Name"
: ""

, "Config, Configs"
: [
  ""

]
, "Description"
: ""

, "Name"
: "이름"

, "Label"
: ""

, "Value"
: ""

, "Default ({0})"
: ""

, "Yes"
: ""

, "No"
: ""

, "Group Name"
: ""

, "Visibility"
: ""

, "Display in addressbook"
: ""

, "Hide from addressbook"
: ""

, "Saved in Addressbook"
: ""

, "E-mail"
: ""

, "Only system accounts can be added to Addressbook group"
: ""

, "Group Members"
: ""

, "Domain is not allowed. Check your SMTP domain configuration."
: ""

, "Confirm"
: ""

, "Do you really want to delete the selected tags?"
: ""

, "Deleting tag(s)..."
: ""

, "Add Tag"
: ""

, "Edit Tag"
: ""

, "Delete Tag"
: ""

, "Search:"
: ""

, "Displaying tags {0} - {1} of {2}"
: ""

, "No tags to display"
: ""

, "ID"
: ""

, "Color"
: ""

, "Usage:&#160;"
: ""

, "Do you really want to delete the selected roles?"
: ""

, "Deleting role(s)..."
: ""

, "Failed"
: ""

, "Some error occurred while trying to delete the role."
: ""

, "Add Role"
: ""

, "Edit Role"
: ""

, "Delete Role"
: ""

, "Displaying roles {0} - {1} of {2}"
: ""

, "No roles to display"
: ""

, "Container Name"
: ""

, "Type"
: ""

, "Container Order"
: ""

, "Container, Containers"
: [
  ""

]
, "Model"
: ""

, "personal"
: ""

, "shared"
: ""

, "Order"
: ""

, "Container Hierarchy/Name"
: ""

, "Note for Owner"
: ""

, "Info"
: ""

, "Please create Resources in Addressbook or CoreData."
: ""

, "Do you really want to delete the selected groups?"
: ""

, "Deleting group(s)..."
: ""

, "Some error occurred while trying to delete the group."
: ""

, "Add Group"
: ""

, "Edit Group"
: ""

, "Delete Group"
: ""

, "Displaying groups {0} - {1} of {2}"
: ""

, "No groups to display"
: ""

, "Account only"
: ""

, "Creation Time"
: ""

, "Created By"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "IP Address"
: "IP 주소"

, "Login Time"
: "로그인 시간"

, "Logout Time"
: "로그아웃 시간"

, "Client Type"
: "사용자 유형"

, "Session ID"
: "세션 ID"

, "Login Name"
: "로그인 이름"

, "Result"
: "결과"

, "User Agent"
: ""

, "user blocked"
: "차단된 사용자"

, "password expired"
: "비밀번호 만료"

, "user disabled"
: "삭제된 사용자"

, "invalid password"
: "비밀번호 오류"

, "ambiguous username"
: "알수 없는 사용자 이름"

, "user not found"
: "사용자 없음"

, "failure"
: "실패"

, "success"
: "성공"

, "Customfield, Customfields"
: [
  ""

]
, "This custom field is still in use!"
: ""

, "Are you sure you want to delete them?"
: ""

, "Errors"
: ""

, "Please configure store for this field type"
: ""

, "Record Class"
: ""

, "Given record class not found"
: ""

, "Cancel"
: ""

, "OK"
: ""

, "Configure store"
: ""

, "Custom field definition"
: ""

, "Text"
: ""

, "Textarea"
: ""

, "Number"
: ""

, "Date"
: ""

, "DateTime"
: ""

, "Time"
: ""

, "Boolean"
: ""

, "Search Combo"
: ""

, "Key Field"
: ""

, "Record"
: ""

, "Record List"
: ""

, "Length"
: ""

, "Required"
: ""

, "Custom field additional properties"
: ""

, "Tab Panel"
: ""

, "Group, Groups"
: [
  ""

]
, "Key"
: ""

, "Customfield already exists. Please choose another name."
: ""

, "Enable Account"
: ""

, "Disable Account"
: ""

, "Reset Password"
: ""

, "Status"
: ""

, "Display name"
: ""

, "Login name"
: ""

, "Last name"
: ""

, "First name"
: ""

, "E-mail usage"
: ""

, "Filesystem usage"
: ""

, "OpenID"
: ""

, "Last login at"
: ""

, "Last login from"
: ""

, "Password Must Change"
: ""

, "Password changed"
: ""

, "Expires"
: ""

, "Set new password"
: ""

, "Please enter the new password:"
: ""

, "Users"
: ""

, "Samba User, Samba Users"
: [
  ""

]
, "Email User, Email Users"
: [
  ""

]
, "Special characters are not allowed in login name."
: ""

, "Passwords do not match!"
: ""

, "Passwords match!"
: ""

, "Primary group"
: ""

, "Unix"
: ""

, "Home Directory"
: ""

, "Login Shell"
: ""

, "Windows"
: ""

, "Home Drive"
: ""

, "never logged in"
: ""

, "Home Path"
: ""

, "never logged off"
: ""

, "Profile Path"
: ""

, "Password Last Set"
: ""

, "never"
: ""

, "Logon Script"
: ""

, "Password Can Change"
: ""

, "not set"
: ""

, "Kick Off Time"
: ""

, "Filesystem Quota"
: ""

, "Quota"
: ""

, "no quota set"
: ""

, "Current Filesystem usage"
: ""

, "IMAP Quota"
: ""

, "Current Mailbox size"
: ""

, "Sieve Quota"
: ""

, "Current Sieve size"
: ""

, "Information"
: ""

, "Last Login"
: ""

, "Forward Only"
: ""

, "E-mail Alias"
: ""

, "Add an alias address..."
: ""

, "This alias can be used for sending e-mails."
: ""

, "Domain not allowed"
: ""

, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
: ""

, "Forwarding to self"
: ""

, "You are not allowed to set a forwarding e-mail address that is identical to the users primary e-mail or one of his aliases."
: ""

, "E-mail Forward"
: ""

, "Add a forwarding address..."
: ""

, "Password confirmation"
: ""

, "Repeat password"
: ""

, "Ok"
: ""

, "Account"
: ""

, "Password"
: ""

, "Multi Factor Authentication Config"
: ""

, "enabled"
: ""

, "disabled"
: ""

, "expired"
: ""

, "blocked"
: ""

, "Invalid Status"
: ""

, "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
: ""

, "don't know"
: ""

, "Password set"
: ""

, "User groups"
: ""

, "User roles"
: ""

, "Fileserver"
: ""

, "Filesystem"
: ""

, "IMAP"
: ""

, "SMTP"
: ""

, "Computer, Computers"
: [
  ""

]
, "Please wait"
: ""

, "Updating Memberships"
: ""

, "Could not save role."
: ""

, "Please fix the errors noted."
: ""

, "Deleting role..."
: ""

, "Rights"
: ""

, "Members"
: ""

, "Role Name"
: ""

, "Transferring {0}..."
: ""

, "Role"
: ""

, "Add New Role"
: ""

, "Edit Role \"{0}\""
: ""

, "Configs"
: ""

, "Size"
: ""

, "Revision Size"
: ""

, "Total size of all available revisions"
: ""

, "Quota Usage"
: ""

, "Updating Tag"
: ""

, "Could not save tag ({0})"
: ""

, "Allowed Contexts"
: ""

, "Context"
: ""

, "Account Rights"
: ""

, "View"
: ""

, "Use"
: ""

, "Tag Name"
: ""

, "Tag"
: ""

, "Add New Tag"
: ""

, "Edit Tag \"{0}\""
: ""

, "Enable Application"
: ""

, "Disable Application"
: ""

, "Settings"
: ""

, "{0} Settings"
: ""

, "Enabled"
: ""

, "Unknown status ({0})"
: ""

, "Displaying application {0} - {1} of {2}"
: ""

, "No applications to display"
: ""

, "Version"
: ""

, "Default password must change for new user settings"
: ""

, "Default IMAP user settings"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Admin Application."
: ""

, "Prevent special chars in login name"
: ""

, "Force retype of new password in user edit dialog"
: ""

, "Your container has been changed"
: ""

, "Your container has been changed by %1$s %2$sNote: %3$s"
: ""

, "Password is needed for system account creation"
: ""

, "Notifications"
: ""

, "Manage access log"
: ""

, "Delete access log entries."
: ""

, "Manage accounts"
: ""

, "Add and edit users and groups, add group members, change user passwords."
: ""

, "Manage e-mail accounts"
: ""

, "Add and edit shared and personal e-mail accounts."
: ""

, "Manage applications"
: ""

, "Enable and disable applications, edit application settings."
: ""

, "Manage roles"
: ""

, "Add and edit roles, add new members to roles, add application rights to roles."
: ""

, "Manage shared tags"
: ""

, "Add, delete and edit shared tags."
: ""

, "Manage computers"
: ""

, "Add, delete and edit (samba) computers."
: ""

, "Manage containers"
: ""

, "Add, delete and edit containers and manage container grants."
: ""

, "Manage customfields"
: ""

, "Add and edit customfields."
: ""

, "Manage import and export definitions"
: ""

, "Add and edit import and export definitions"
: ""

, "View access log"
: ""

, "View access log list."
: ""

, "View accounts"
: ""

, "View accounts list and details."
: ""

, "View e-mail accounts"
: ""

, "View shared and personal e-mail accounts."
: ""

, "View applications"
: ""

, "View applications list and details."
: ""

, "View roles"
: ""

, "View roles list and details."
: ""

, "View shared tags"
: ""

, "View shared tags list and details."
: ""

, "View computers"
: ""

, "View computers list and details."
: ""

, "View containers"
: ""

, "View personal and shared containers."
: ""

, "View customfields"
: ""

, "View customfields list."
: ""

, "View serverinfo"
: ""

, "View serverinfo list."
: ""

, "View quota usage"
: ""

, "View quota usage."
: ""

, "view ImportExportDefinitions"
: ""









, "ImportExportDefinition"
: ""

, "Application"
: ""

, "User"
: "사용자"

, "Access Log"
: "접속 로그"

, "Config"
: ""

, "Container"
: ""

, "Customfield"
: ""

, "Group"
: ""

, "Samba User"
: ""

, "Email User"
: ""

, "Computer"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
